@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-""" glogarchive v 0.5 (C) 2010 by Kurt Fleisch
+""" glogarchive v 0.7 (C) 2010 by Kurt Fleisch
     http://www.bananenfisch.net/n900/
 
     This program is free software: you can redistribute it and/or modify
@@ -35,7 +35,7 @@ class fenster:
         self.about.set_name("glogarchive")
         self.about.set_logo_icon_name("glogarchive")
         self.about.set_comments("to archive SMS/IM messages and calling-history from the eventlogger to an extra DB")
-        self.about.set_version("0.5")
+        self.about.set_version("0.7")
         self.about.set_copyright("by Kurt Fleisch")
         gtk.about_dialog_set_url_hook(self.openurl, self.about)
         self.about.set_website("www.bananenfisch.net/n900")
@@ -63,11 +63,11 @@ class fenster:
         self.archivedb = True
         self.viewall = True
         self.window = hildon.StackableWindow()
-        self.window.set_title("glogevent")
+        self.window.set_title("glogarchive")
         self.window.connect("delete_event", self.close_application)
         self.window.set_border_width(0)
 
-        self.osso_c = osso.Context("glogarchive", "0.5", False)
+        self.osso_c = osso.Context("glogarchive", "0.7", False)
         self.osso_rpc = osso.Rpc(self.osso_c)
 
         gmenu = hildon.AppMenu()
@@ -89,7 +89,7 @@ class fenster:
         gmenu.show_all()
         self.window.set_app_menu(gmenu)
 
-        columns = boxlines = gtk.HBox(False, 0)
+        columns = gtk.HBox(False, 0)
 
         boxlines = gtk.VBox(False, 0)
 
@@ -129,7 +129,7 @@ class fenster:
 
         boxlines.show()
 
-        left = gtk.VBox(False, 5)
+        left = gtk.VBox(False, 0)
 
         self.butcharch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Switch to Live-Database")
         self.butcharch.connect("clicked", change_db)
@@ -154,6 +154,18 @@ class fenster:
         left.pack_end(butcsv, False, False, 0)
         butcsv.show()
 
+        searches = gtk.HBox(False, 0)
+        self.entry = hildon.Entry(0)
+        self.entry.set_max_length(100)
+        butsearch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Find")
+        butsearch.connect("clicked", searchall)
+        searches.pack_start(self.entry, True, True, 0)
+        searches.pack_start(butsearch, True, True, 0)
+        left.pack_end(searches, False, False, 0)
+        self.entry.show()
+        butsearch.show()
+        searches.show()
+
         left.show()
 
         separator = gtk.VSeparator()
@@ -249,7 +261,7 @@ def listall(widget, filter = False):
     conn = sqlite3.connect(pfad)
     cur = conn.cursor()
     if filter == False:
-      cur.execute("select eventtypes.name, count(events.id) from eventtypes LEFT JOIN events ON events.event_type_id = eventtypes.id group by eventtypes.id order by eventtypes.id")
+      cur.execute("select events.event_type_id, count(events.id) from events group by events.event_type_id order by events.event_type_id")
       ui.viewall = True
     else:
       ui.viewall = False
@@ -261,7 +273,7 @@ def listall(widget, filter = False):
       daten2 = "%d-%02d-%02d" % (byear, bmonth, bday)
       stampfrom = time.mktime(time.strptime(daten1, "%Y-%m-%d"))
       stampto = time.mktime(time.strptime(daten2+" 23:59:59", "%Y-%m-%d %H:%M:%S"))
-      cur.execute("select eventtypes.name, count(events.id) from eventtypes LEFT JOIN events ON events.event_type_id = eventtypes.id where events.start_time >= ? and events.start_time <= ? group by eventtypes.id order by eventtypes.id", (stampfrom, stampto))
+      cur.execute("select events.event_type_id, count(events.id) from events where events.start_time >= ? and events.start_time <= ? group by events.event_type_id order by events.event_type_id", (stampfrom, stampto))
     for row in cur:
       sumzeile = gtk.HBox(False, 0)
       label1 = gtk.Label("%s:" % (gettype(row[0])))
@@ -290,7 +302,7 @@ def viewuid(widget):
 
   if os.path.isfile(pfad):
     winuid = hildon.StackableWindow()
-    winuid.set_title("glogevent: uid")
+    winuid.set_title("glogarchive: uid")
     winuid.set_border_width(0)
     gruppen = gtk.VBox(False, 0)
     scrolled_window = hildon.PannableArea()
@@ -335,7 +347,7 @@ def viewevt(widget):
 
   if os.path.isfile(pfad):
     winuid = hildon.StackableWindow()
-    winuid.set_title("glogevent: event")
+    winuid.set_title("glogarchive: event")
     winuid.set_border_width(0)
 
     gruppen = gtk.VBox(False, 0)
@@ -349,7 +361,7 @@ def viewevt(widget):
     for row in cur:
       button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
       button.set_style(hildon.BUTTON_STYLE_PICKER)
-      button.set_text(gettype(row[1]), row[1])
+      button.set_text(gettype(row[0]), row[1])
       button.set_alignment(0, 0, 0, 0)
       button.connect("clicked", viewdetail, row[0], "event")
       gruppen.pack_start(button, False, False, 0)
@@ -374,7 +386,7 @@ def viewdetail(widget, did, viewtype):
     pfad = EL_PATH
 
   winuid = hildon.StackableWindow()
-  winuid.set_title("glogevent: "+str(did))
+  winuid.set_title("glogarchive: "+str(did))
   winuid.set_border_width(0)
 
   gruppen = gtk.VBox(False, 0)
@@ -385,7 +397,7 @@ def viewdetail(widget, did, viewtype):
   conn = sqlite3.connect(pfad)
   cur = conn.cursor()
   if viewtype == "user":
-    cur.execute("select Eventtypes.name, Events.start_time, Events.free_text, Events.remote_uid from Events left join Eventtypes on Events.event_type_id = Eventtypes.id where substr(Events.remote_uid, -7) = ? order by Events.start_time desc", (did,))
+    cur.execute("select Events.event_type_id, Events.start_time, Events.free_text, Events.remote_uid from Events where substr(Events.remote_uid, -7) = ? order by Events.start_time desc", (did,))
   else:
     cur.execute("select Remotes.remote_name, Events.start_time, Events.free_text, Events.remote_uid from Events left join Remotes on Events.remote_uid = Remotes.remote_uid where Events.event_type_id = ? order by Events.start_time desc", (did,))
   for row in cur:
@@ -413,6 +425,50 @@ def viewdetail(widget, did, viewtype):
   winuid.show()
   cur.close()
 
+def searchall(widget):
+  if ui.archivedb == True:
+    pfad = ARCHIVE_PATH
+  else:
+    pfad = EL_PATH
+
+  sstr = ui.entry.get_text()
+  if sstr != "":
+    thistitle = sstr
+    sstr = "%"+sstr+"%"
+    winuid = hildon.StackableWindow()
+    winuid.set_title("search for "+thistitle)
+    winuid.set_border_width(0)
+  
+    gruppen = gtk.VBox(False, 0)
+    scrolled_window = hildon.PannableArea()
+    winuid.add(scrolled_window)
+    scrolled_window.add_with_viewport(gruppen)
+  
+    conn = sqlite3.connect(pfad)
+    cur = conn.cursor()
+    cur.execute("select Remotes.remote_name, Events.start_time, Events.free_text, Events.remote_uid, Events.event_type_id from Events left join Remotes on Events.remote_uid = Remotes.remote_uid where Events.free_text like ? or Events.remote_uid like ? or Remotes.remote_name like ? order by Events.start_time desc", (sstr, sstr, sstr))
+    for row in cur:
+      lasttime = time.strftime("%d.%m.%Y %H:%M:%S", time.localtime(row[1]))
+      if row[0] == None:
+        ol1 = "%s: %s <small>(%s)</small>" % (gettype(row[4]), cgi.escape(row[3]), lasttime)
+      else:
+        ol1 = "%s: %s <small>(%s, %s)</small>" % (gettype(row[4]), cgi.escape(row[0]), cgi.escape(row[3]), lasttime)
+      if row[2] != None: ol1 = ol1 + "\n<small><i>" + cgi.escape(row[2]) + "</i></small>"
+      button = gtk.Label()
+      button.set_markup(ol1)
+      button.set_alignment(0, 0)
+      button.set_line_wrap(True)
+      gruppen.pack_start(button, False, False, 3)
+      sep = gtk.HSeparator()
+      gruppen.pack_start(sep, False, False, 3)
+      sep.show()
+      button.show()
+  
+    gruppen.show()
+    scrolled_window.show()
+    winuid.show()
+    cur.close()
+
 def export_csv(widget):
   if ui.archivedb == True:
     pfad = ARCHIVE_PATH
@@ -465,14 +521,14 @@ def change_db(widget):
     listall(ui, True)
 
 def gettype(typename):
-  if typename == "RTCOM_EL_EVENTTYPE_CALL_INBOUND": return "in CALL"
-  if typename == "RTCOM_EL_EVENTTYPE_CALL_OUTBOUND": return "out CALL"
-  if typename == "RTCOM_EL_EVENTTYPE_CALL_MISSED": return "missed CALL"
-  if typename == "RTCOM_EL_EVENTTYPE_CALL_VOICEMAIL": return "voicemail CALL"
-  if typename == "RTCOM_EL_EVENTTYPE_CHAT_INBOUND": return "in CHAT"
-  if typename == "RTCOM_EL_EVENTTYPE_CHAT_OUTBOUND": return "out CHAT"
-  if typename == "RTCOM_EL_EVENTTYPE_SMS_INBOUND": return "in SMS"
-  if typename == "RTCOM_EL_EVENTTYPE_SMS_OUTBOUND": return "out SMS"
+  if typename == 1: return "in CALL"
+  if typename == 2: return "out CALL"
+  if typename == 3: return "missed CALL"
+  if typename == 4: return "voicemail CALL"
+  if typename == 5: return "in CHAT"
+  if typename == 6: return "out CHAT"
+  if typename == 7: return "in SMS"
+  if typename == 8: return "out SMS"
   return "unknown type"
 
 if __name__ == "__main__":
